@@ -1,8 +1,8 @@
 #/*##########################################################################
-# Copyright (C) 2004-2021 European Synchrotron Radiation Facility
+# Copyright (C) 2004-2023 European Synchrotron Radiation Facility
 #
 # This file is part of the PyMca X-ray Fluorescence Toolkit developed at
-# the ESRF by the Software group.
+# the ESRF.
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the "Software"), to deal
@@ -23,7 +23,7 @@
 # THE SOFTWARE.
 #
 #############################################################################*/
-__author__ = "V.A. Sole - ESRF Data Analysis"
+__author__ = "V.A. Sole - ESRF"
 __contact__ = "sole@esrf.fr"
 __license__ = "MIT"
 __copyright__ = "European Synchrotron Radiation Facility, Grenoble, France"
@@ -191,7 +191,7 @@ class MaskScatterWidget(PlotWindow.PlotWindow):
         image = numpy.histogram2d(y[idx], x[idx],
                                   bins=bins,
                                   #range=(binsY, binsX),
-                                  normed=False)
+                                  density=False)
         self._binsX = image[2]
         self._binsY = image[1]
         self._bins = bins
@@ -240,7 +240,7 @@ class MaskScatterWidget(PlotWindow.PlotWindow):
         self.yScale = (y0, deltaY)
         binsX = numpy.arange(bins[0]) * deltaX
         binsY = numpy.arange(bins[1]) * deltaY
-        image = numpy.histogram2d(y[idx], x[idx], bins=(binsY, binsX), normed=False)
+        image = numpy.histogram2d(y[idx], x[idx], bins=(binsY, binsX), density=False)
         self._binsX = image[2]
         self._binsY = image[1]
         self._bins = bins
@@ -258,13 +258,13 @@ class MaskScatterWidget(PlotWindow.PlotWindow):
                     mask = numpy.round(numpy.histogram2d(y[idx], x[idx],
                                        bins=(binsY, binsX),
                                        weights=weights,
-                                       normed=True)[0] * weightsSum * volume).astype(numpy.uint8)
+                                       density=True)[0] * weightsSum * volume).astype(numpy.uint8)
                 else:
                     #print("GOOD PATH")
                     mask = numpy.histogram2d(y[idx], x[idx],
                                              bins=(binsY, binsX),
                                              weights=weights,
-                                             normed=False)[0]
+                                             density=False)[0]
                     mask[mask > 0] = 1
                 #print(mask.min(), mask.max())
                 self._densityPlotWidget.setSelectionMask(mask, plot=False)
@@ -648,7 +648,7 @@ class MaskScatterWidget(PlotWindow.PlotWindow):
                                        self._setBrush5)
             self._brushMenu.addAction(QString("20 Image Pixel Width"),
                                        self._setBrush6)
-        self._brushMenu.exec_(self.cursor().pos())
+        self._brushMenu.exec(self.cursor().pos())
 
     def _brushSelectionIconSignal(self):
         _logger.debug("_setBrushSelectionMode")
@@ -782,9 +782,9 @@ class MaskScatterWidget(PlotWindow.PlotWindow):
 
     def _additionalIconSignal(self):
         if self._plotViewMode == "density": # and imageData is not none ...
-            self._additionalSelectionMenu["density"].exec_(self.cursor().pos())
+            self._additionalSelectionMenu["density"].exec(self.cursor().pos())
         else:
-            self._additionalSelectionMenu["scatter"].exec_(self.cursor().pos())
+            self._additionalSelectionMenu["scatter"].exec(self.cursor().pos())
 
     def __resetSelection(self):
         # Needed because receiving directly in _resetSelection it was passing
@@ -930,7 +930,7 @@ class MaskScatterWidget(PlotWindow.PlotWindow):
                 column = int((x[i] - x0) /deltaX)
                 try:
                     value = densityPlotMask[row, column]
-                except:
+                except Exception:
                     if row >= densityPlotMask.shape[0]:
                         row = densityPlotMask.shape[0] - 1
                     if column >= densityPlotMask.shape[1]:
@@ -1009,5 +1009,5 @@ if __name__ == "__main__":
     w.setPolygonSelectionMode()
     w.sigMaskScatterWidgetSignal.connect(receivingSlot)
     w.show()
-    app.exec_()
+    app.exec()
 
